"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RecurringRepayments = void 0;
const baseResource_1 = require("./baseResource");
class RecurringRepayments extends baseResource_1.BaseResource {
    constructor(token, basePath, config) {
        super(token, basePath + "/recurring-repayments", config);
    }
    async create(request) {
        return this.httpPost("", { data: request });
    }
    async get(repaymentId) {
        return this.httpGet(`/${repaymentId}`);
    }
    async disable(repaymentId) {
        // NB: We must pass an empty body here because the API is returning a 415 for any requests made
        //  to this endpoint from this SDK: Content-Type must be application/vnd.api+json
        //  However, there is code in Axios that strips the Content-Type from the request whenever 
        //  there is no body since it makes no sense to provide it + makes the data over the wire
        //  that much smaller:  
        //   https://github.com/axios/axios/blob/649d739288c8e2c55829ac60e2345a0f3439c730/dist/axios.js#L1449-L1450
        // TODO: Remove the empty body after we update the API to not throw 415 for missing Content-Type 
        //  when the body is empty.
        return this.httpPost(`/${repaymentId}/disable`, { data: {} });
    }
    async enable(repaymentId) {
        // NB: We must pass an empty body here because the API is returning a 415 for any requests made
        //  to this endpoint from this SDK: Content-Type must be application/vnd.api+json
        //  However, there is code in Axios that strips the Content-Type from the request whenever 
        //  there is no body since it makes no sense to provide it + makes the data over the wire
        //  that much smaller:  
        //   https://github.com/axios/axios/blob/649d739288c8e2c55829ac60e2345a0f3439c730/dist/axios.js#L1449-L1450
        // TODO: Remove the empty body after we update the API to not throw 415 for missing Content-Type 
        //  when the body is empty.
        return this.httpPost(`/${repaymentId}/enable`, { data: {} });
    }
    async list(params) {
        const parameters = {
            "page[limit]": ((params === null || params === void 0 ? void 0 : params.limit) ? params.limit : 100),
            "page[offset]": ((params === null || params === void 0 ? void 0 : params.offset) ? params.offset : 0),
            ...((params === null || params === void 0 ? void 0 : params.creditAccountId) && { "filter[creditAccountId]": params.creditAccountId }),
            ...((params === null || params === void 0 ? void 0 : params.customerId) && { "filter[customerId]": params.customerId }),
            ...((params === null || params === void 0 ? void 0 : params.status) && { "filter[status]": params.status }),
            ...((params === null || params === void 0 ? void 0 : params.fromStartTime) && { "filter[fromStartTime]": params.fromStartTime }),
            ...((params === null || params === void 0 ? void 0 : params.toStartTime) && { "filter[toStartTime]": params.toStartTime }),
            "sort": (params === null || params === void 0 ? void 0 : params.sort) ? params.sort : "-createdAt"
        };
        if (params === null || params === void 0 ? void 0 : params.status)
            params.status.forEach((s, idx) => {
                parameters[`filter[status][${idx}]`] = s;
            });
        return this.httpGet("", { params: parameters });
    }
}
exports.RecurringRepayments = RecurringRepayments;
