import { BaseListParams, Statement, UnitConfig, UnitResponse } from "../types";
import { BaseResource } from "./baseResource";
import { responseEncoding, ResponseType } from "axios";
export declare class Statments extends BaseResource {
    constructor(token: string, basePath: string, config?: UnitConfig);
    list(params?: StatementsListParams): Promise<UnitResponse<Statement[]>>;
    get(statementId: string, customerId?: string, isPDF?: boolean, responseEncoding?: responseEncoding, language?: "en" | "es"): Promise<string>;
    getBinary(statementId: string, customerId?: string, isPDF?: boolean, language?: "en" | "es"): Promise<string>;
    getBankVerification(accountId: string, includeProofOfFunds?: boolean, responseEncoding?: responseEncoding, responseType?: ResponseType): Promise<string>;
}
export interface StatementsListParams extends BaseListParams {
    /**
     * Optional. Filters the results by the specified account id.
     * default: empty
     */
    accountId?: string;
    /**
     * Optional. Filters the results by the specified customer id.
     * default: empty
     */
    customerId?: string;
    /**
     * Optional. sort=period for ascending order. Provide sort=-period (leading minus sign) for descending order.
     * default: sort=-period
     */
    sort?: "period" | "-period";
    /**
     * Optional. Filters the results for a specific month. e.g. 2021-01
     * ISO8601 Date string
     */
    period?: string;
    /**
     * Optional. Filters the results by the specified account ids.
     */
    accountIds?: string[];
}
